@@ -311,16 +311,6 @@ pub mod {{> filename }} {
     }
     {{~/inline}}
 
-    fn err_to_string(err: &dyn std::error::Error) -> String {
-        let mut errors_str = Vec::new();
-        let mut current_err = err.source();
-        while let Some(err) = current_err {
-            errors_str.push(err.to_string());
-            current_err = err.source();
-        }
-        format!("error: {}\n\ncaused by:\n\t{}", err, errors_str.as_slice().join("\n\t"))
-    }
-
     {{#each paths}}
         {{~#with get}}{{~> operation_fn title=../../info.title noBody=true}}{{~/with}}
         {{~#with head}}{{~> operation_fn title=../../info.title noBody=true}}{{~/with}}
@@ -366,10 +356,14 @@ pub mod {{> filename }} {
             )
         {{~/each}}
             .app_data(actix_web::web::JsonConfig::default()
-                .error_handler(|err, _| {
-                    let mut response = HttpResponseBuilder::new(StatusCode::BAD_REQUEST);
-                    response.body(err_to_string(&err));
-                    InternalError::from_response(err, response.into()).into()
+                .error_handler(|err, req| {
+                    let response = HttpResponse::BadRequest().body(
+                        serde_json::to_string(
+                            &<Server as {{camelcase info.title}}>::handle_error(&req, &err)
+                        ).unwrap(),
+                    );
+
+                    InternalError::from_response(err, response).into()
                 })
             );
     }
